﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Fluke ScopeMeter Identification RS-232
INSTRUMENT:            Sub Fluke ScopeMeter Instrument Status RS-232
INSTRUMENT:            Sub Fluke ScopeMeter Query Measurement RS-232
INSTRUMENT:            Sub Fluke ScopeMeter Read Date RS-232
INSTRUMENT:            Sub Fluke ScopeMeter Read Time RS-232
INSTRUMENT:            Sub Fluke ScopeMeter Status RS-232
DATE:                  2018-02-02 09:24:27
AUTHOR:                Fluke
REVISION:              $Revision: 22480 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       7
NUMBER OF LINES:       253
=============================================================================
#
#  Procedure Author:
#        DAC, VY
#
#  Compatibilty:
#        MET/CAL 8.0 and later
#
# This procedure is intended for use with MET/CAL® calibration software; the
# terms and conditions set forth in your MET/CAL license apply to this
# procedure.
#
# Due to Fluke's policy of continuously updating our products, this procedure
# may contain minor differences in methods used and/or specifications to
# those found in the manual or other documentation. While every effort has
# been made to ensure that this procedure is accurate, Fluke cannot be held
# responsible for the consequences of error or omissions found within this
# procedure.
#
# The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  JMPL         IDENTIFICATION               PSUB("Identification")
  1.002  JMPL         INSTRUMENT_STATUS            PSUB("Instrument Status")
  1.003  JMPL         QUERY_MEASUREMENT            PSUB("Query Measurement")
  1.004  JMPL         READ_DATE                    PSUB("Read Date")
  1.005  JMPL         READ_TIME                    PSUB("Read Time")
  1.006  JMPL         STATUS                       PSUB("Status")
  1.007  DISP         Subprocedure not found!
  1.008  END

  1.009  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Identification RS-232  ========================

# This subprocedure queries the Test Tool for its configuration information.

  2.001  LABEL        IDENTIFICATION
  2.002  MATH         @Cmd = "ID"
  2.003  CALL         Sub Fluke ScopeMeter Send Command RS-232

  2.004  IF           @Abort
  2.005  END
  2.006  ENDIF

  2.007  PORT         [I$]

# Some ScopeMeters return an ID string with 2 or more consecutive whitespace.
# Example:
#
# "ScopeMeter  96B Series II; V8.20; 96005-07; English V8.05; ; UHM V1.0"
#
# This screws up parsing using the MATH FLD function.
# Convert multiple whitespace to single whitespace.
  2.008  MATH         DoubleSpace = FIND(MEM2, "  ", 1)

  2.009  WHILE        DoubleSpace
  2.010  MATH         MEM2 = REPL("  ", " ", MEM2)
  2.011  MATH         DoubleSpace = FIND(MEM2, "  ", 1)
  2.012  ENDW

# Parse ID response into fields based on semicolon separator.
# Field 1: Manufacturer and model
# Field 2: Firmware version
# Field 3: Firmware date
# Field 4: Supported languages.
  2.013  MATH         MfrModel      = STRIP(FLD(MEM2, 1, ";"))
  2.014  MATH         @FirmwareRev  = STRIP(FLD(MEM2, 2, ";"))
  2.015  MATH         @FirmwareDate = STRIP(FLD(MEM2, 3, ";"))
  2.016  MATH         Language      = STRIP(FLD(MEM2, 4, ";"))

# Parse MfrModel subfield based on white space separator.
# Field 1: Manufacturer
# Field 2: Model number; "model" for Series I units
# Field 3: Model number (Series I), "Series" for Series II units
  2.017  MATH         @Manufacturer = FLD(MfrModel, 1, " ")
  2.018  MATH         @ModelNum     = FLD(MfrModel, 2, " ")
  2.019  MATH         ModelFld3     = FLD(MfrModel, 3, " ")

  2.020  MATH         @Series_I = 0; @Series_II = 0

# Series I ScopeMeters send:
#   "ScopeMeter model <model #> ; <firmware> ; <date>
  2.021  IF           ZCMPI(@ModelNum, "model")
  2.022  MATH         @Series_I = 1
  2.023  MATH         @ModelNum = ModelFld3

# Series II ScopeMeters send:
#   "ScopeMeter <model #> Series II; <firmware>; <date>; <language>; ...
  2.024  ELSEIF       FINDI(ModelFld3, "Series II", 1)
  2.025  MATH         @Series_II = 1
  2.026  MATH         @ModelNum = @ModelNum & " Series II"
  2.027  ENDIF

# Deletes leading zero, e.g., 043, if present.
  2.028  IF           ZCMP(SUB(@ModelNum, 1, 1), "0")
  2.029  MATH         @ModelNum = SUB(@ModelNum, 2, LEN(@ModelNum))
  2.030  ENDIF

  2.031  MATH         FirmwareRev = "Firmware Version: " & @FirmwareRev
  2.032  HEAD         INSTALLED INSTRUMENT FIRMWARE
  2.033  DISP         Manufacturer : [V @Manufacturer]
  2.033  DISP         Model        : [V @ModelNum]
  2.033  DISP         Firmware Rev.: [V @FirmwareRev]
  2.033  DISP         Firmware Date: [V @FirmwareDate]
  2.034  RSLT         =
  2.035  RSLT         =[V FirmwareRev]

  2.036  HEAD
  2.037  END

  2.038  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Instrument Status RS-232  =====================

  3.001  LABEL        INSTRUMENT_STATUS
  3.002  MATH         @Cmd = "IS"
  3.003  CALL         Sub Fluke ScopeMeter Send Command RS-232

  3.004  IF           NOT(@Abort)
  3.005  PORT         [I]
  3.006  ENDIF

  3.007  END

  3.008  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Query Measurement RS-232  =====================

# These subprocedures check the queried measurement value of Input A (B)
# for invalid (9.91e37) or overload (9.9e37 or -9.9e37).  If 5x invalid or
# overload then result is fail.
#
# @Cmd must contain the Query Measurement command (e.g., QM 11) when
# this subprocedure is called.
#
# @Wait = number of seconds to delay before taking measurement

  4.001  LABEL        QUERY_MEASUREMENT
# Set invalid/overload measurement counter.
  4.002  MATH         Counter = 5

  4.003  DO

  4.004  IF           @Wait > 1
  4.005  WAIT         -t [V @Wait] System settling...
  4.006  ELSE
  4.007  WAIT         [D1000]
  4.008  ENDIF

  4.009  CALL         Sub Fluke ScopeMeter Send Command RS-232

  4.010  IF           NOT(@Abort)
# Read measurement.
  4.011  PORT         [I]
  4.012  MATH         Counter = Counter - 1
  4.013  ENDIF

# Repeat if invalid reading or overload condition.
  4.014  UNTIL        (Counter <= 0) || (ABS(MEM) < 1E+10) || @Abort

  4.015  END

  4.016  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Read Date RS-232  =============================

  5.001  LABEL        READ_DATE
  5.002  MATH         @Cmd = "RD"
  5.003  CALL         Sub Fluke ScopeMeter Send Command RS-232

  5.004  IF           NOT(@Abort)
  5.005  PORT         [I$]
  5.006  ENDIF

  5.007  END

  5.008  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Read Time RS-232  =============================

  6.001  LABEL        READ_TIME
  6.002  MATH         @Cmd = "RT"
  6.003  CALL         Sub Fluke ScopeMeter Send Command RS-232

  6.004  IF           NOT(@Abort)
  6.005  PORT         [I$]
  6.006  ENDIF

  6.007  END

  6.008  EVAL   Increment Test Number

# =====  Sub Fluke ScopeMeter Status RS-232  ================================

  7.001  LABEL        STATUS
  7.002  MATH         @Cmd = "ST"
  7.003  CALL         Sub Fluke ScopeMeter Send Command RS-232

  7.004  IF           @Abort
  7.005  END
  7.006  ENDIF

  7.007  PORT         [I]

  7.008  IF           BIT(0, MEM)
  7.009  DISP         Illegal command.
  7.010  ELSEIF       BIT(1, MEM)
  7.011  DISP         Data format of parameter is wrong.
  7.012  ELSEIF       BIT(2, MEM)
  7.013  DISP         Parameter out of range.
  7.014  ELSEIF       BIT(3, MEM)
  7.015  DISP         Invalid command in this CPL interface.
  7.016  ELSEIF       BIT(4, MEM)
  7.017  DISP         Command not implemented.
  7.018  ELSEIF       BIT(5, MEM)
  7.019  DISP         Invalid number of parameters.
  7.020  ELSEIF       BIT(6, MEM)
  7.021  DISP         Wrong number of data bits.
  7.022  ELSEIF       BIT(7, MEM)
  7.023  DISP         Flash ROM not present.
  7.024  ELSEIF       BIT(8, MEM)
  7.025  DISP         Invalid flash software.
  7.026  ELSEIF       BIT(9, MEM)
  7.027  DISP         Conflicting instrument settings.
  7.028  ELSEIF       BIT(10, MEM)
  7.029  DISP         User Request (URQ).
  7.030  ELSEIF       BIT(11, MEM)
  7.031  DISP         Flash ROM not programmable.
  7.032  ELSEIF       BIT(12, MEM)
  7.033  DISP         Wrong programming voltage.
  7.034  ELSEIF       BIT(13, MEM)
  7.035  DISP         Invalid key string.
  7.036  ELSEIF       BIT(14, MEM)
  7.037  DISP         Checksum error.
  7.038  ENDIF

  7.039  END
